#setup.py - Free Rider HD Installation script
#by maxmillion18
#http://www.github.com/maxmillion18
#http://www.freeriderhd.com/u/MaxwellNurzia

from setuptools import setup, find_packages

versionFile = "VERSION"
setup(name="frhdtools",
    version=open(versionFile).read(),
    description="Library to work with Free Rider HD Tracks",
    long_description="Frhdtools is a library for working with Free Rider HD Tracks.",
    url="https://github.com/maxmillion18/frhdtools",
    author="maxmillion18",
    author_email="icantpostmyemailhere@gmail.com",
    license="MIT License",
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Code Generators",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3 :: Only"
    ],
    keywords="development freeriderhd freerider code track tracks",
    packages=find_packages(exclude=["images"]),
)



#Decode.py - Freerider HD object decoder
#by maxmillion18
#http://www.github.com/maxmillion18
#http://www.freeriderhd.com/u/MaxwellNurzia

import re #need it

LINE_RE = re.compile('(?P<x1>-?\S*) (?P<y1>-?\S*) (?P<x2>-?\S*) (?P<y2>-?[^ ,#])')
PUP__RE = re.compile('(?P<type>(C|T|S|O)) (?P<x>-?\S*) (?P<y>-?[^ ,#])')
PUPR_RE = re.compile('(?P<type>(G|B)) (?P<x>-?\S*) (?P<y>-?\S*) (?P<rot>-?[^ ,#])')

def decline(ls): #Decode line
    return LINE_RE.match(ls).groupdict()

def decpup(pup): #Decode powerup
    return PUP__RE.match(pup).groupdict()

def decpupr(pupr): #Decode powerup with rotation
    return PUPR_RE.match(pupr).groupdict()

def b32d(n): #Base 32 decode
    return int(n, 32)
